@@ -1,9 +1,14 @@
 module Option where
 
 import qualified State
-import Option.Utility (exitFailureMsg, parseNumber, fmapOptDescr)
 import Degree (Degree(Degree, getDegree))
 
+import qualified Shell.Utility.Verbosity as Verbosity
+import Shell.Utility.Verbosity (Verbosity)
+import Shell.Utility.ParseArgument (parseNumber)
+import Shell.Utility.Exit (exitFailureMsg)
+import Shell.Utility.GetOpt (fmapOptDescr)
+
 import qualified System.Console.GetOpt as Opt
 import qualified System.Environment as Env
 import System.Console.GetOpt (ArgDescr(NoArg, ReqArg), getOpt, usageInfo)
@@ -13,7 +18,7 @@ import qualified System.IO as IO
 
 import Control.Monad (when)
 
-import qualified Data.EnumSet as EnumSet
+import qualified Data.EnumBitSet as EnumSet
 import qualified Data.Vector as Vector
 import qualified Data.Map as Map
 import qualified Data.List.HT as ListHT
@@ -22,10 +27,6 @@ import Data.Tuple.HT (mapSnd)
 import Data.Monoid ((<>))
 import Data.Word (Word8)
 
-import qualified Distribution.Verbosity as Verbosity
-import qualified Distribution.ReadE as ReadE
-import Distribution.Verbosity (Verbosity)
-
 import Text.Printf (printf)
 
 
@@ -153,10 +154,8 @@ optionDescription desc =
       "show options" :
 
    opt generic ['v'] ["verbose"]
-      (flip ReqArg "N" $ \str flags -> do
-         case ReadE.runReadE Verbosity.flagToVerbosity str of
-            Right n -> return (flags{verbosity = n})
-            Left msg -> exitFailureMsg msg)
+      (flip ReqArg "N" $ \str flags ->
+         fmap (\verb -> flags{verbosity = verb}) $ Verbosity.parse str)
       (printf "verbosity level: 0..3, default: %d"
          (fromEnum $ verbosity defltOption)) :
 
